#!/usr/bin/env python

import os

import click


@click.command()
@click.argument("edited_file")
def main(edited_file: str) -> None:
    """
    This code does nothing on purpose. This is to be used as a git
    editor, and automatically commit the files.
    """
    custom_message = os.environ.get("GIT_MONOREPO_EDITOR_MESSAGE", "")

    if not custom_message:
        return

    # we write the custom message at the top
    message = [custom_message]

    with open(edited_file, "rt", encoding="utf-8") as f:
        for line in f.readlines():
            if not line.startswith("#"):
                message.append(line)

    with open(edited_file, "wt", encoding="utf-8") as f:
        f.write("\n".join(message))


if __name__ == "__main__":
    main()



from setuptools import setup
from setuptools import find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

packages = find_packages()

setup(
    name="git_monorepo",
    version="1.4.0",
    description="git_monorepo",
    long_description=readme,
    author="Bogdan Mustiata",
    author_email="bogdan.mustiata@gmail.com",
    license="BSD",
    entry_points={
        "console_scripts": [
            "git-mono = git_monorepo.mainapp:main",
            "git-monorepo-editor = git_monorepo.editorapp:main",
        ]
    },
    install_requires=[
        "PyYAML==5.3.1",
        "click==7.1.2",
    ],
    packages=packages,
    package_data={
        "": ["*.txt", "*.rst"],
        "git_monorepo": ["py.typed"],
    },
)
